###DOmake.a2d.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

unset noclobber

if ($#argv < 1) then
   echo "usage: DOmake.a2d.page.plot   <date.ext>"
   echo " (produces profile ps file named A2D.yyyymmdd.dat.ps)"
   exit
endif

# Change these Lower/Upper ranges as necessary:
set A2D_RANGE     = 0/4095
set A2D_TIC     = "a2g2f1"

# Don't change these:
set HR_RANGE       = 0./24.       ; set HR_TIC       = "2g1::"

cd $DIRUWDATA/MET

set DATE = $1

set IFN = `$BINDIR/ins_filename $DATE`

# test for a compressed file if exists then uncompress it
if ( -e $IFN.Z) then
	uncompress $IFN
endif

# test for the data file to exist
if !( -e $IFN) then
	echo "DOmake.a2d.page.plot: No data file: $IFN"
	exit
endif

#test if any analog to digital data exists

grep ^INSA2D $IFN > /dev/null
if ( $status == 1) then
	compress -f $IFN
	exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = A2D.$IFN.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.8
   set XOFF1 = 1.2 ; set YOFF1 =  8.0
   set XOFF2 = 0.0 ; set YOFF2 = -2.3
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "A2D data  $CRUISE  $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`


###################### start 1st panel ######################################
#
# First a2d channel

$BINDIR/a2d_data.awk n=1 scale=2 $IFN > 2col

set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$A2D_TIC":"Channel 1(V)":
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

if ( ! -z 2col ) then
	psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
	psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
	psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
endif

###################### end panel ############################################


###################### start 2nd panel ######################################

$BINDIR/a2d_data.awk n=2 scale=2 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$A2D_TIC":"Channel 2(V)":
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

if ( ! -z 2col ) then
	psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
	psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
	psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
endif
####################### end panel ############################################

###################### start 3nd panel ######################################

$BINDIR/a2d_data.awk n=3 scale=2 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$A2D_TIC":"Channel 3(V)":
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

if ( ! -z 2col ) then
	psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
	psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
	psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
endif
####################### end panel ############################################

###################### start 4nd panel ######################################

$BINDIR/a2d_data.awk n=4 scale=2 $IFN > 2col

set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/`cat range`
set XTIC   = "$HR_TIC"
set YTIC   = "$A2D_TIC":"Channel 4(V)":
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"

if ( ! -z 2col ) then
	psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0
	psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
	psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
endif
####################### end panel ############################################
#
#
#

### finish off the postscript file ##########################################
pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
#
# Print the file
#
lp -d hp8000 $OFN

#compress files:
compress -f $IFN
#end
